package com.three_petals.activity;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.res.Configuration;
import android.os.Bundle;
import android.support.v4.app.ActionBarDrawerToggle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.support.v4.view.GravityCompat;
import android.support.v4.widget.DrawerLayout;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;

import com.example.three_petals.R;
import com.three_petals.activity.content.NewsFragment;

public class MainMenu extends FragmentActivity implements ListView.OnItemClickListener
{
    private final static String[] menuTitles = { "News", "Photo", };

    private DrawerLayout drawerLayout;
    private ListView listView;

    private ActionBarDrawerToggle drawerToggle;

    public static void AffMainMenu(Context context)
    {
        Intent t = new Intent(context, MainMenu.class);
        context.startActivity(t);

        Activity activity = (Activity) context;
        activity.finish();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.menu_main);

        drawerLayout = (DrawerLayout) findViewById(R.id.main_drawer);
        listView = (ListView) findViewById(R.id.left_drawer);

        listView.setAdapter(new ArrayAdapter<String>(this, R.layout.menu_item, menuTitles));
        listView.setOnItemClickListener(this);

        drawerLayout.setDrawerShadow(R.drawable.drawer_shadow, GravityCompat.START);

        getActionBar().setDisplayHomeAsUpEnabled(true);
        getActionBar().setHomeButtonEnabled(true);

        drawerToggle = new ActionBarDrawerToggle(this, drawerLayout, R.drawable.ic_drawer, R.string.drawer_open, R.string.drawer_close) {
            public void onDrawerClosed(View view)
            {
                invalidateOptionsMenu();
            }

            public void onDrawerOpened(View drawerView)
            {
                invalidateOptionsMenu();
            }
        };
        drawerLayout.setDrawerListener(drawerToggle);
        
        if (savedInstanceState == null)
        {
            selectItem(0);
        }
    }

    @Override
    protected void onPostCreate(Bundle savedInstanceState)
    {
        super.onPostCreate(savedInstanceState);
        drawerToggle.syncState();
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig)
    {
        super.onConfigurationChanged(newConfig);
        drawerToggle.onConfigurationChanged(newConfig);
    }

    @Override
    public void onItemClick(AdapterView<?> parent, View view, int index, long id)
    {
        selectItem(index);
    }
    
    private void selectItem(int index)
    {
        Fragment fragment = null;
        
        switch (index)
        {
            case 0:
                fragment = new NewsFragment();
                break;
                
            case 1:
                TakePhotoActivity.affTakePhoto(this);
                return;
        }
        
        if (fragment == null)
        {
            return;
        }
        
        FragmentManager manager = getSupportFragmentManager();
        manager.beginTransaction().replace(R.id.content_frame, fragment).commit();
        
        listView.setItemChecked(index, true);
        drawerLayout.closeDrawer(listView);
    }
}
